@@ -87,7 +87,7 @@ class Hoe
   include Rake::DSL if defined?(Rake::DSL)
 
   # duh
-  VERSION = "4.2.4"
+  VERSION = "4.5.1"
 
   @@plugins = [:clean, :debug, :deps, :flay, :flog, :newb, :package,
                :publish, :gemcutter, :signing, :test]
@@ -181,6 +181,11 @@ class Hoe
 
   attr_accessor :extra_dev_deps
 
+  ##
+  # Optional: rdoc arguments to be used when generating rdoc.
+
+  attr_accessor :rdoc_options
+
   ##
   # Optional: Extra files you want to add to RDoc.
   #
@@ -423,7 +428,8 @@ class Hoe
     names.reject! { |n| n =~ /^[A-Z_]+$/ }
 
     names.each do |name|
-      next unless Hoe.plugins.include? name.downcase.intern
+      underscored = name.gsub(/(?<!^)(?=[A-Z])/, "_").downcase.intern
+      next unless Hoe.plugins.include? underscored
       warn "extend #{name}" if $DEBUG
       self.extend Hoe.const_get(name)
     end
@@ -544,7 +550,7 @@ class Hoe
       s.bindir               = bindir || "bin"
       s.executables          = s.files.grep(/^#{s.bindir}/) { |f| File.basename(f) }
       s.require_paths        = dirs unless dirs.empty?
-      s.rdoc_options         = ["--main", readme_file]
+      s.rdoc_options         = rdoc_options
       s.post_install_message = post_install_message
       s.metadata             = (urls.keys & URLS_TO_META_MAP.keys).map { |name|
         [URLS_TO_META_MAP[name], urls[name]]
@@ -663,6 +669,9 @@ class Hoe
     self.history_file ||= Dir.glob("History.{rdoc,txt,md}").first || "History.txt"
     self.readme_file  ||= Dir.glob("README.{rdoc,txt,md}").first || "README.txt"
 
+    # delayed to set readme_file first
+    self.rdoc_options = ["--main", readme_file]
+
     abort "Hoe.new {...} removed. Switch to Hoe.spec." if block_given?
   end
 
@@ -953,15 +962,8 @@ end
 class File # :nodoc:
   # Like File::read, but strips out a BOM marker if it exists.
   def self.read_utf path
-    r19 = "<3".respond_to? :encoding
-    opt = r19 ? "r:bom|utf-8" : "rb"
-
-    open path, opt do |f|
-      if r19 then
-        f.read
-      else
-        f.read.sub %r%\A\xEF\xBB\xBF%, ""
-      end
+    open path, "r:bom|utf-8" do |f|
+      f.read
     end
   end
 end
